@@ -1,7 +1,7 @@
 context("Freeman segregation index")
 
 test_that("Freeman index is 0 for full network", {
-  g <- graph.full(10, directed=FALSE)
+  g <- make_full_graph(10, directed=FALSE)
   V(g)$type <- rep(1:2, length=vcount(g))
   expect_that( freeman(g, "type"), equals(0))
 } )
