@@ -3,6 +3,6 @@ context("Testing SMI")
 test_that("SMI works", {
   data("WhiteKinship")
   expect_silent(
-    smi(as.directed(WhiteKinship), "gender")
+    smi(as_directed(WhiteKinship), "gender")
   )
 } )
